roc.guest.models
================

This directory contains the migrations auto generated by Alembic:

- check the generated code
- adjust the code if needed

Note:

- You can change the name of migrations for something more friendly
- Generation of the initial revision can be done with the following command:
    ```
    pop -ll INFO db makemigrations roc.guest \
        --rev-id='roc_guest_0001_initial' \
        --branch-label='gse' \
        --head="poppy_pop_0001_initial"
    ```
    the --head= keyword is required to run the command, but down_revision can be let to None after file generation
- Make sure to create the 'gse' schema in the initial revision and to get the expected user permissions
- The 'gse' schema is not deleted by initial downgrade migration
